//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// Program        : JFrame Demo
//
// Author         : Richard E. Pattis
//                  Computer Science Department
//                  Carnegie Mellon University
//                  5000 Forbes Avenue
//                  Pittsburgh, PA 15213-3891
//                  e-mail: pattis@cs.cmu.edu
//
// Maintainer     : Author
//
//
// Description:
//
//   A simple program that illustrates how to use javax.swing.JFrame.
// The console controls this window appearing and disappearing. The
// JFrame's size is always at 1/2 the width/height of the screen. Its
// header includes an icon and title (which changes slightly, via
// a counter/location, each time the window appears). The window's
// location changes each time it disappears. When the window is closed,
// the entire program terminates (including the loop in main).
//
// Things to try:
//    use a different gif for the header
//    don't add the window listener
//    ensure when window is moved randomly, it is always fully on the screen
//       (use the Toolkit to account for its width/height when randomizing)
//    override other methods in the WindowAdapter
// 
// 
// 
// Known Bugs     : None
//
// Future Plans   : None
//
// Program History:
//    11/21/04: R. Pattis - Operational for 15-200
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////


package basicJFrame;


import java.awt.Dimension;
import java.awt.Image;
import java.awt.Toolkit;

import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JFrame;



class View extends JFrame {

  //Instance Variables
  
  //For title icon and size/positioning of JFrame
  private Toolkit   tk      = Toolkit.getDefaultToolkit();  
  private Dimension screen  = tk.getScreenSize();
  private int     showCount = 0;
  private String  originalMessage;
 
 
  public View()
  {
    addWindowListener(new WindowAdapter() {
      public void windowClosing(WindowEvent e)
      { 
        System.out.println("\nEvent = " + e);
        System.out.println("Window closing selected: terminating program");
        System.exit(0);
      }
    });
  }


  public void build (String message, String gifFileName)
  {
    setTitle(originalMessage = message);
    
    //Title icon
    Image titleIcon = tk.getImage(gifFileName);
    setIconImage(titleIcon);
    
    //1/2 Screen Height/Width, Positioned in the Middle
    setSize    (screen.width/2, screen.height/2);
    setLocation(screen.width/4, screen.height/4);
  }

  
  //Override the inherited setVisible method.
  //Whenever it is made visible, change its title slightly.
  //Whenever it is made invisible, move its location randomly
  public void setVisible(boolean visible)
  {
    if (!isVisible() && visible)       //going from invisible to visible?
      setTitle(originalMessage + " (shown " + ++showCount + " times): now at " + getLocation());
    else if (isVisible() && !visible)  //going from visible to invisible?
      setLocation( (int)(Math.random()*1000),(int)(Math.random()*1000)); 
    super.setVisible(visible);
  }  
}